@@ -6,8 +6,8 @@
 ;; Author: Phil Hagelberg, Cornelius Mika, Campbell Barton
 ;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; URL: https://codeberg.org/ideasman42/emacs-idle-highlight-mode
-;; Package-Version: 20251126.1130
-;; Package-Revision: 4f5183c480c3
+;; Package-Version: 20260108.1311
+;; Package-Revision: 83aa002c837f
 ;; Created: 2008-05-13
 ;; Keywords: convenience
 ;; EmacsWiki: IdleHighlight
@@ -32,7 +32,7 @@
 ;;; Code:
 
 (eval-when-compile
-  ;; For `pcase-dolist'.
+  ;; For the byte-compiler to find: `pcase-dolist'.
   (require 'pcase))
 
 
@@ -66,7 +66,7 @@
            (function :tag "A function that takes a list of faces, non-nil result excludes.")))
 
 (defcustom idle-highlight-exceptions-syntax "^w_"
-  "Syntax table to to skip.
+  "Syntax table to skip.
 
 See documentation for `skip-syntax-forward', nil to ignore."
   :type '(choice (const nil) string))
@@ -112,8 +112,8 @@ check this buffer.")
 ;; Internal Functions
 
 (defun idle-highlight--faces-at-point (pos)
-  "Add the named faces that the `read-face-name' or `face' property use.
-Argument POS return faces at this point."
+  "Return the named faces that the `read-face-name' or `face' property use.
+Argument POS is the position to return faces for."
   (declare (important-return-value t))
   (let ((faces nil) ; List of faces to return.
         ;; NOTE: use `get-text-property' instead of `get-char-property' so overlays are excluded,
@@ -177,7 +177,7 @@ Where RANGES is an unordered list of (min . max) cons cells."
               (zerop (skip-syntax-forward idle-highlight-exceptions-syntax (1+ pos))))
             (progn
               (goto-char pos)
-              (zerop (skip-syntax-backward idle-highlight-exceptions-syntax pos)))))
+              (zerop (skip-syntax-backward idle-highlight-exceptions-syntax (1- pos))))))
        (t
         (goto-char pos)
         (zerop (skip-syntax-forward idle-highlight-exceptions-syntax (1+ pos)))))))
@@ -280,10 +280,10 @@ should be the result of `idle-highlight--word-at-point-args'."
 ;; - The timer is kept active as long as the local mode is enabled.
 ;; - Entering a buffer runs the buffer local `window-state-change-hook'
 ;;   immediately which checks if the mode is enabled,
-;;   set up the global timer if it is.
-;; - Switching any other buffer wont run this hook,
-;;   rely on the idle timer it's self running, which detects the active mode,
-;;   canceling it's self if the mode isn't active.
+;;   sets up the global timer if it is.
+;; - Switching any other buffer won't run this hook,
+;;   rely on the idle timer itself running, which detects the active mode,
+;;   canceling itself if the mode isn't active.
 ;;
 ;; This is a reliable way of using a global,
 ;; repeating idle timer that is effectively buffer local.
@@ -293,7 +293,7 @@ should be the result of `idle-highlight--word-at-point-args'."
 (defvar idle-highlight--global-timer nil)
 ;; When t, the timer will update buffers in all other visible windows.
 (defvar idle-highlight--dirty-flush-all nil)
-;; When true, the buffer should be updated when inactive.
+;; When t, the buffer should be updated when inactive.
 (defvar-local idle-highlight--dirty nil)
 
 (defun idle-highlight--time-callback-or-disable ()
@@ -390,7 +390,7 @@ should be the result of `idle-highlight--word-at-point-args'."
       (setq idle-highlight--global-timer nil)))))
 
 (defun idle-highlight--time-reset ()
-  "Run this when the buffer change was changed."
+  "Run when the buffer changes."
   (declare (important-return-value nil))
   ;; Ensure changing windows doesn't leave other buffers with stale highlight.
   (cond
@@ -441,7 +441,7 @@ should be the result of `idle-highlight--word-at-point-args'."
          (not (bound-and-true-p idle-highlight-mode))
          ;; Not in the mini-buffer.
          (null (minibufferp))
-         ;; Not a special mode (package list, tabulated data ... etc)
+         ;; Not a special mode (package list, tabulated data, etc.)
          ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
          (null (derived-mode-p 'special-mode))
          ;; Not explicitly ignored.
